@@ -1,6 +1,5 @@
 #include <algorithm>
-#include <iostream>
-#include <complex>
+#include <cmath>
 
 extern "C" {
     void findNN_ (int *m_, int *n_, double *q_, double *vec_, int *NN_) {
@@ -15,8 +14,8 @@ extern "C" {
             NN_[i] = dist ;
 
             if (dist > 0){
-                d1 = fabs(q_[i] - vec_[dist - 1]);
-                d2 = fabs(q_[i] - vec_[dist]);
+                d1 = std::fabs(q_[i] - vec_[dist - 1]);
+                d2 = std::fabs(q_[i] - vec_[dist]);
 
                 if (d1 < d2)
                     NN_[i] = dist - 1 ;
